@@ -30,6 +30,7 @@ def check_file(subdir: str, filename: str, *, data: bool = True) -> None:
         fast=args.fast,
         minimum_version=args.minimum_version,
         lines=args.lines,
+        no_preview_line_length_1=args.no_preview_line_length_1,
     )
     if args.minimum_version is not None:
         major, minor = args.minimum_version
@@ -42,6 +43,7 @@ def check_file(subdir: str, filename: str, *, data: bool = True) -> None:
             fast=args.fast,
             minimum_version=args.minimum_version,
             lines=args.lines,
+            no_preview_line_length_1=args.no_preview_line_length_1,
         )
 
 
@@ -85,4 +87,6 @@ def test_patma_invalid() -> None:
     with pytest.raises(black.parsing.InvalidInput) as exc_info:
         assert_format(source, expected, mode, minimum_version=(3, 10))
 
-    exc_info.match("Cannot parse: 10:11")
+    exc_info.match(
+        "Cannot parse for target version Python 3.10: 10:11:     case a := b:"
+    )
